#[repr(transparent)]pub struct Ringo1Ctrl(pub u32);Expand description
Second Ring Oscillator module control register.
Tuple Fields
0: u32Implementations
Sourceimpl Ringo1Ctrl
impl Ringo1Ctrl
Sourcepub const fn s(&self) -> Ringo1CtrlS
pub const fn s(&self) -> Ringo1CtrlS
Select short or long ringo (for all ringos types).
Sourcepub const fn set_s(&mut self, val: Ringo1CtrlS)
pub const fn set_s(&mut self, val: Ringo1CtrlS)
Select short or long ringo (for all ringos types).
Sourcepub const fn fs(&self) -> Ringo1CtrlFs
pub const fn fs(&self) -> Ringo1CtrlFs
Ringo frequency output divider.
Sourcepub const fn set_fs(&mut self, val: Ringo1CtrlFs)
pub const fn set_fs(&mut self, val: Ringo1CtrlFs)
Ringo frequency output divider.
Sourcepub const fn pd(&self) -> Ringo1CtrlPd
pub const fn pd(&self) -> Ringo1CtrlPd
Ringo module Power control.
Sourcepub const fn set_pd(&mut self, val: Ringo1CtrlPd)
pub const fn set_pd(&mut self, val: Ringo1CtrlPd)
Ringo module Power control.
Sourcepub const fn divisor(&self) -> u8
pub const fn divisor(&self) -> u8
Ringo out Clock divider value. Frequency Output = Frequency input / (DIViSOR+1). (minimum = Frequency input / 16)
Sourcepub const fn set_divisor(&mut self, val: u8)
pub const fn set_divisor(&mut self, val: u8)
Ringo out Clock divider value. Frequency Output = Frequency input / (DIViSOR+1). (minimum = Frequency input / 16)
Sourcepub const fn div_update_req(&self) -> bool
pub const fn div_update_req(&self) -> bool
Ringo clock out Divider status flag. Set when a change is made to the divider value, cleared when the change is complete.
Sourcepub const fn set_div_update_req(&mut self, val: bool)
pub const fn set_div_update_req(&mut self, val: bool)
Ringo clock out Divider status flag. Set when a change is made to the divider value, cleared when the change is complete.