#[repr(transparent)]pub struct Xo32mCtrl(pub u32);Expand description
High speed Crystal Oscillator Control register
Tuple Fields
0: u32Implementations
Sourceimpl Xo32mCtrl
impl Xo32mCtrl
Sourcepub const fn osc_cap_in(&self) -> u8
pub const fn osc_cap_in(&self) -> u8
Tune capa banks of High speed Crystal Oscillator input pin
Sourcepub const fn set_osc_cap_in(&mut self, val: u8)
pub const fn set_osc_cap_in(&mut self, val: u8)
Tune capa banks of High speed Crystal Oscillator input pin
Sourcepub const fn osc_cap_out(&self) -> u8
pub const fn osc_cap_out(&self) -> u8
Tune capa banks of High speed Crystal Oscillator output pin
Sourcepub const fn set_osc_cap_out(&mut self, val: u8)
pub const fn set_osc_cap_out(&mut self, val: u8)
Tune capa banks of High speed Crystal Oscillator output pin
Sourcepub const fn acbuf_pass_enable(&self) -> bool
pub const fn acbuf_pass_enable(&self) -> bool
Bypass enable of XO AC buffer enable in pll and top level.
Sourcepub const fn set_acbuf_pass_enable(&mut self, val: bool)
pub const fn set_acbuf_pass_enable(&mut self, val: bool)
Bypass enable of XO AC buffer enable in pll and top level.
Sourcepub const fn enable_pll_usb_out(&self) -> bool
pub const fn enable_pll_usb_out(&self) -> bool
Enable High speed Crystal oscillator output to USB HS PLL.
Sourcepub const fn set_enable_pll_usb_out(&mut self, val: bool)
pub const fn set_enable_pll_usb_out(&mut self, val: bool)
Enable High speed Crystal oscillator output to USB HS PLL.
Sourcepub const fn enable_system_clk_out(&self) -> bool
pub const fn enable_system_clk_out(&self) -> bool
Enable High speed Crystal oscillator output to CPU system.
Sourcepub const fn set_enable_system_clk_out(&mut self, val: bool)
pub const fn set_enable_system_clk_out(&mut self, val: bool)
Enable High speed Crystal oscillator output to CPU system.